@@ -20,7 +20,8 @@ from log import get_file_logger, safe_print
 from meta import name as appname
 from options import debug, test, verbose
 from wxwindows import (BaseApp, BaseFrame, BitmapBackgroundPanel, CustomCheckBox,
-					   CustomGrid, FlatShadedButton, numpad_keycodes)
+					   CustomGrid, FlatShadedButton, numpad_keycodes,
+					   wx_Panel)
 import CGATS
 import audio
 import colormath
@@ -44,7 +45,7 @@ class UntetheredFrame(BaseFrame):
 		self.sizer.AddGrowableCol(0)
 		self.sizer.AddGrowableRow(0)
 		self.sizer.AddGrowableRow(1)
-		self.panel = wx.Panel(self)
+		self.panel = wx_Panel(self)
 		self.SetSizer(self.sizer)
 		self.sizer.Add(self.panel, 1, wx.EXPAND)
 		self.panel.SetBackgroundColour(BGCOLOUR)
@@ -253,7 +254,7 @@ class UntetheredFrame(BaseFrame):
 	def Resume(self):
 		self.keepGoing = True
 	
-	def Update(self, value, msg=""):
+	def UpdateProgress(self, value, msg=""):
 		return self.Pulse(msg)
 	
 	def UpdatePulse(self, msg=""):
@@ -426,7 +427,7 @@ class UntetheredFrame(BaseFrame):
 			self.update(self.index + 1)
 
 	def parse_txt(self, txt):
-		if not txt or not self.keepGoing:
+		if not txt:
 			return
 		self.logger.info("%r" % txt)
 		data_len = len(self.cgats[0].DATA)
@@ -439,7 +440,7 @@ class UntetheredFrame(BaseFrame):
 				row = self.cgats[0].DATA[i]
 				RGB = []
 				for j, label in enumerate("RGB"):
-					value = int(round(float(str(row["RGB_%s" % label] * 2.55))))
+					value = int(round(row["RGB_%s" % label] / 100.0 * 255))
 					self.grid.SetCellValue(row.SAMPLE_ID - 1, j, "%i" % value)
 					RGB.append(value)
 				self.grid.SetCellBackgroundColour(row.SAMPLE_ID - 1, 3,
@@ -534,7 +535,7 @@ class UntetheredFrame(BaseFrame):
 							self.grid.MakeCellVisible(self.index, 0)
 		if "key to take a reading" in txt and not self.last_error:
 			if getcfg("untethered.measure.auto") and self.is_measuring:
-				if not self.finished:
+				if not self.finished and self.keepGoing:
 					self.measure()
 				else:
 					self.enable_btns()
@@ -616,10 +617,10 @@ class UntetheredFrame(BaseFrame):
 	
 	def show_RGB(self, clear_XYZ=True, mark_current_row=True):
 		row = self.cgats[0].DATA[self.index]
-		self.label_RGB.SetLabel("RGB %i %i %i" % (round(row["RGB_R"] * 2.55),
-												  round(row["RGB_G"] * 2.55),
-												  round(row["RGB_B"] * 2.55)))
-		color = [int(round(v * 2.55)) for v in
+		self.label_RGB.SetLabel("RGB %i %i %i" % (round(row["RGB_R"] / 100.0 * 255),
+												  round(row["RGB_G"] / 100.0 * 255),
+												  round(row["RGB_B"] / 100.0 * 255)))
+		color = [int(round(v / 100.0 * 255)) for v in
 				 (row["RGB_R"], row["RGB_G"], row["RGB_B"])]
 		self.panel_RGB.SetBackgroundColour(wx.Colour(*color))
 		self.panel_RGB.SetBitmap(None)
